<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AboutPage</name>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>A bicycle sharing application. It allows you to find free bikes or stations near you. It currently supports every system handled by &lt;em&gt;Nextbike&lt;/em&gt; including more than 80 cities from Germany, Austria, Latvia, Poland, Switzerland, Turkey, Azerbaijan, Cyprus, the United Arabian Emirates and New Zealand.</source>
        <translation>Aplikacja do obsługi systemu rowerów publicznych. Pozwala na znalezienie wolnych rowerów lub stacji. Obecnie działa we wszystkich systemach obsługiwanych przez firmę &lt;em&gt;Nextbike&lt;/em&gt;, czyli w ponad 80 miastach z Niemiec, Austrii, Łotwy, Polski, Szwajcarii, Turcji, Azerbejdżanu, Cypru, Zjednoczonych Emiratów Arabskich i Nowej Zelandii. W przypadku Polski, aplikacja współpracuje z warszawskim systemem Veturilo, BemowoBike, Wrocławskim Rowerem Miejskim (WRM), OpoleBike oraz z Poznańskim Rowerem Miejskim (PRM).</translation>
    </message>
</context>
<context>
    <name>BusyPane</name>
    <message>
        <source>updating...</source>
        <translation type="obsolete">aktualizacja...</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Aktualizacja...</translation>
    </message>
</context>
<context>
    <name>FirstRunPage</name>
    <message>
        <source>Select your city</source>
        <translation>Wybierz miasto</translation>
    </message>
    <message>
        <source>Updating data...</source>
        <translation>Aktualizuję dane...</translation>
    </message>
</context>
<context>
    <name>PlacePage</name>
    <message>
        <source>or more free bikes</source>
        <translation>lub więcej rowerów</translation>
    </message>
    <message>
        <source>free bikes</source>
        <translation>dostępnych rowerów</translation>
    </message>
    <message>
        <source>free bike</source>
        <translation>dostępny rower</translation>
    </message>
    <message>
        <source>no free bikes</source>
        <translation>brak rowerów</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Save settings</source>
        <translation>Zapisz ustawienia</translation>
    </message>
    <message>
        <source>Restart for the change to take effect!</source>
        <translation>Ponownie uruchom aplikacje!</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>GPS interval (ms)</source>
        <translation>Częstotliwość GPS</translation>
    </message>
    <message>
        <source>Search radius (m)</source>
        <translation>Promień szukania</translation>
    </message>
    <message>
        <source>Search timeout (ms)</source>
        <translation type="obsolete">Czas szukania</translation>
    </message>
    <message>
        <source>Choose your language</source>
        <translation>Wybierz język</translation>
    </message>
    <message>
        <source>Enable GPS</source>
        <translation>Włącz GPS</translation>
    </message>
    <message>
        <source>Choose your language:</source>
        <translation>Wybierz swój język:</translation>
    </message>
</context>
<context>
    <name>SplashPane</name>
    <message>
        <source>loading...</source>
        <translation>wczytywanie...</translation>
    </message>
</context>
<context>
    <name>StationsList</name>
    <message>
        <source>or more free bikes</source>
        <translation>lub więcej rowerów</translation>
    </message>
    <message>
        <source>free bikes</source>
        <translation>dostępne rowery</translation>
    </message>
    <message>
        <source>free bike</source>
        <translation>dostępny rower</translation>
    </message>
    <message>
        <source>no free bikes</source>
        <translation>brak rowerów</translation>
    </message>
</context>
<context>
    <name>StationsPage</name>
    <message>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Can&apos;t find stations :-(</source>
        <translation>Brak stacji w pobliżu :-(</translation>
    </message>
    <message>
        <source>Updating data...</source>
        <translation>Aktualizacja...</translation>
    </message>
    <message>
        <source>Finding nearest stations...</source>
        <translation>Szukam najbliższych stacji...</translation>
    </message>
    <message>
        <source>GPS is disabled!</source>
        <translation>GPS jest wyłączony!</translation>
    </message>
    <message>
        <source>Waiting for GPS...</source>
        <translation>Czekam na sygnał GPS...</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Change city</source>
        <translation>Zmień miasto</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O Cyklopie</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
</TS>
